{% load cms_tags %}{% spaceless %}

{# this needs to be in one line for rendering purpose #}
{% endspaceless %}<a href="{{ link }}"{% if instance.target %} target="{{ instance.target }}"{% endif %}{% if instance.attributes %} {{ instance.attributes_str }}{% endif %}>{% for plugin in instance.child_plugin_instances %}{% render_plugin plugin %}{% empty %}{{ instance.name }}{% endfor %}</a>{% spaceless %}

{% endspaceless %}{% comment %}
# https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a
    {{ instance.name }}
    {{ link }} or {{ instance.get_link }} summarizes:
        {{ instance.external_link }}
        {{ instance.internal_link }}
        {{ instance.anchor }}
        {{ instance.mailto }}
        {{ instance.phone }}
    {{ instance.target }}
    {{ instance.attributes_str }}
{% endcomment %}