# Generated by Django 2.2.2 on 2019-06-20 04:49

import django.db.models.deletion
from django.db import migrations

import filer.fields.file


class Migration(migrations.Migration):

    dependencies = [
        ('filer', '0011_auto_20190418_0137'),
        ('djangocms_link', '0013_fix_hostname'),
    ]

    operations = [
        migrations.AddField(
            model_name='link',
            name='file_link',
            field=filer.fields.file.FilerFileField(blank=True, help_text='If provided links a file from the filer app.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='filer.File', verbose_name='File link'),
        ),
    ]
